@@ -5,6 +5,8 @@ import datetime
 import time
 import tempfile
 import shutil
+import yaml
+
 from .randomutils import uuid4
 
 def mkdir(folder):
@@ -143,9 +145,24 @@ def first_exists_file(*filenames, default=None):
     for filename in filenames:
         filename = expand(filename)
         if os.path.exists(filename):
-            return filename
+            return os.path.abspath(filename)
     return default
 
+def get_application_config_paths(appname, name="config", suffix="yml"):
+    return expands(
+        "./{0}-{1}.{2}".format(appname, name, suffix),
+        "./conf/{0}-{1}.{2}".format(appname, name, suffix),
+        "./etc/{0}-{1}.{2}".format(appname, name, suffix),
+        "~/.{0}/{1}.{2}".format(appname, name, suffix),
+        "~/{0}/{1}.{2}".format(appname, name, suffix),
+        "./{0}.{1}".format(name, suffix),
+        "./conf/{0}.{1}".format(name, suffix),
+        "./etc/{0}.{1}".format(name, suffix),
+        "~/{0}.{1}".format(name, suffix),
+        "~/.{0}.{1}".format(name, suffix),
+        "{0}.{1}".format(name, suffix),
+    )
+
 def get_application_config_filepath(appname, name="config", suffix="yml"):
     """Get application config filepath by search these places:
         ./{appname}-{name}.{suffix}
@@ -153,14 +170,30 @@ def get_application_config_filepath(appname, name="config", suffix="yml"):
         ./etc/{appname}-{name}.{suffix}
         ~/.{appname}/{name}.{suffix}
         ~/{appname}/{name}.{suffix}
+        ./{name}.{suffix}
+        ./conf/{name}.{suffix}
+        ./etc/{name}.{suffix}
+        ~/{name}.{suffix}
+        ~/.{name}.{suffix}
+        {name}.{suffix}
     """
-    return first_exists_file(
-        "./{0}-{1}.{2}".format(appname, name, suffix),
-        "./conf/{0}-{1}.{2}".format(appname, name, suffix),
-        "./etc/{0}-{1}.{2}".format(appname, name, suffix),
-        "~/.{0}/{1}.{2}".format(appname, name, suffix),
-        "~/{0}/{1}.{2}".format(appname, name, suffix),
-    )
+    paths = get_application_config_paths(appname, name, suffix)
+    return first_exists_file(*paths)
+
+def load_application_config(appname, name="config", suffix="yml"):
+    """Load application config.
+    """
+    filename = get_application_config_filepath(appname, name, suffix)
+    if not filename:
+        return {}
+    else:
+        with open(filename, "rb") as fobj:
+            data = yaml.safe_load(fobj)
+        if not data:
+            return {}
+        if not isinstance(data, dict):
+            return {}
+        return data
 
 def info(filename):
     ext = os.path.splitext(filename)[1]
@@ -235,3 +268,4 @@ class TemporaryFile(object):
             os.unlink(self.filepath)
         if os.path.exists(self.workspace):
             os.rmdir(self.workspace)
+
